classify_substitution

Function classify_substitution 

pub fn classify_substitution(
    codon1: &[u8],
    codon2: &[u8],
    code: &GeneticCode,
) -> SubstitutionClass
Classify the substitution between two codons that differ at exactly one position.

If the codons are identical or differ at more than one position, the classification is based on the amino acid change (or lack thereof).