Module masking

Module masking 

Low-complexity and repeat masking for biological sequences.

Implements DUST (DNA), SEG (protein), tandem repeat detection, and soft/hard masking application.

Structs

DustParams
Parameters for the DUST low-complexity filter (DNA).
MaskResult
Result of applying a mask to a sequence.
MaskedRegion
A region identified for masking.
SegParams
Parameters for the SEG low-complexity filter (protein).
TandemRepeatParams
Parameters for tandem repeat detection.

Enums

MaskMode
How to mask identified regions.
MaskSource
Source algorithm that identified a masked region.

Functions

apply_mask
Apply masking to a sequence given a set of regions.
dust
Identify low-complexity regions in a DNA sequence using the DUST algorithm.
find_tandem_repeats
Find tandem repeat regions in a sequence.
mask_dust
Run DUST and apply masking in one step.
mask_seg
Run SEG and apply masking in one step.
seg
Identify low-complexity regions in a protein sequence using the SEG algorithm.