Low-complexity and repeat masking for biological sequences.
Implements DUST (DNA), SEG (protein), tandem repeat detection, and soft/hard masking application.
Structs
- Dust
Params - Parameters for the DUST low-complexity filter (DNA).
- Mask
Result - Result of applying a mask to a sequence.
- Masked
Region - A region identified for masking.
- SegParams
- Parameters for the SEG low-complexity filter (protein).
- Tandem
Repeat Params - Parameters for tandem repeat detection.
Enums
- Mask
Mode - How to mask identified regions.
- Mask
Source - Source algorithm that identified a masked region.
Functions
- apply_
mask - Apply masking to a sequence given a set of regions.
- dust
- Identify low-complexity regions in a DNA sequence using the DUST algorithm.
- find_
tandem_ repeats - Find tandem repeat regions in a sequence.
- mask_
dust - Run DUST and apply masking in one step.
- mask_
seg - Run SEG and apply masking in one step.
- seg
- Identify low-complexity regions in a protein sequence using the SEG algorithm.